<html>

<head>
    <title>Request reset password</title>
</head>

<body>
    <h1>Request password reset</h1>
    <div>
        <p>
            Click the link below to reset your password:
            <a href="http://localhost:3000/password-reset/{{token}}">http://localhost:3000/password-reset/{{token}}</a>
        </p>
    </div>
</body>

</html>
